@@ -110,6 +110,7 @@ class ClientAPI:
                 client_socket.connection.recv(client_socket.message_size)
 
     def forward(self, **inputs):
+        # logger.info('CLIENT FORWARD')
         thread_id = threading.get_ident().to_bytes(length=Config.thread_id_len, byteorder='big', signed=False)
 
         if thread_id not in self.client_sockets:
@@ -132,11 +133,13 @@ class ClientAPI:
             client_socket.request_server()
 
         while received_counter < len(outputs):
+            # logger.info('SELECTING')
             ready_sockets: List[ClientSocket] = select.select(
                 client_sockets if batched_inputs else
                 [client_socket for client_socket in client_sockets if client_socket.message_id is not None],
                 [], [], None
             )[0]
+            # logger.info('SELECTED')
             input_sockets: List[ClientSocket] = []
             output_sockets: List[ClientSocket] = []
             for client_socket in ready_sockets:
@@ -149,7 +152,9 @@ class ClientAPI:
             self.clear_sockets(input_sockets)
 
             for ind, (inputs, client_socket) in enumerate(zip(batched_inputs, selected_sockets)):
+                # logger.info('SENDING INPUTS')
                 client_socket.send_inputs(inputs, cur_ind + ind)
+                # logger.info('INPUTS SENT')
 
             cur_ind += added_connections
 
@@ -161,7 +166,9 @@ class ClientAPI:
                         client_socket.cancel_request()
 
             for client_socket in output_sockets:
+                # logger.info('RECEIVING DATA')
                 socket_outputs = client_socket.receive_outputs()
+                # logger.info('RECEIVED DATA')
                 if socket_outputs is None:
                     continue
                 batch_ind, data = socket_outputs
@@ -170,7 +177,9 @@ class ClientAPI:
                 if batched_inputs:
                     client_socket.request_server()
 
-        return self.stack_outputs(outputs)
+        output = self.stack_outputs(outputs)
+        # logger.info('STACKED')
+        return output
 
     def __call__(self, **kwargs):
         return self.forward(**kwargs)
