@@ -28,14 +28,14 @@ class ServerSocket(SocketConnection):
 
     def receive_message(self):
         try:
-            response = self.connection.recv(self.message_size)
-            if not response:
+            request_message = self.connection.recv(self.message_size)
+            if not request_message:
                 raise ConnectionError('No response, other side probably died')
         except ConnectionError:
             self.alive = False
             raise
-        response = response.split(Config.request_cancelled)[-1]
-        if not response:
+        request_message = request_message.split(Config.request_cancelled)[-1]
+        if not request_message:
             return None
         self.connection.send(Config.request_signal)
         response = self.read_buffer()
